@@ -1,11 +1,12 @@
-# -*- coding: future_annotations -*-
+# -*- coding: utf-8 -*-
 from typing import TYPE_CHECKING
 
+import pyccolo as pyc
 from traitlets.config.configurable import SingletonConfigurable
 
 if TYPE_CHECKING:
     from nbsafety.safety import NotebookSafety as NotebookSafetyInstance
-    from nbsafety.tracing.trace_manager import TraceManager as TraceManagerInstance
+    from nbsafety.tracing.nbsafety_tracer import SafetyTracer as TracerInstance
 
 
 class NotebookSafety(SingletonConfigurable):
@@ -18,15 +19,15 @@ class NotebookSafety(SingletonConfigurable):
         self.__class__._Xyud34_INSTANCE = self
 
 
-class TraceManager(SingletonConfigurable):
+class SingletonBaseTracer(pyc.BaseTracer):
     pass
 
 
-def nbs() -> NotebookSafetyInstance:
+def nbs() -> "NotebookSafetyInstance":
     assert NotebookSafety.initialized()
     return NotebookSafety.instance()
 
 
-def tracer() -> TraceManagerInstance:
-    assert TraceManager.initialized()
-    return TraceManager.instance()
+def tracer() -> "TracerInstance":
+    assert SingletonBaseTracer.initialized()
+    return SingletonBaseTracer.instance()
