@@ -1,26 +1,29 @@
-# -*- coding: future_annotations -*-
+# -*- coding: utf-8 -*-
 import ast
-from typing import TYPE_CHECKING
+import textwrap
+from typing import Dict
 
-from nbsafety.tracing.stmt_mapper import StatementMapper
+from nbsafety.singletons import tracer
+from pyccolo.stmt_mapper import StatementMapper
+from .utils import make_safety_fixture
 
-if TYPE_CHECKING:
-    from typing import Dict
+
+_safety_fixture, _ = make_safety_fixture()
 
 
 def compute_lineno_to_stmt_mapping(code: str) -> Dict[int, ast.stmt]:
-    mapper = StatementMapper(0, {}, {}, {})
-    mapper(ast.parse(code))
+    mapper = StatementMapper({}, [tracer()], {})
+    mapper(ast.parse(textwrap.dedent(code).strip()))
     return mapper.line_to_stmt_map
 
 
 def test_for_loop():
     code = """
-for i in range(10):
-    a: int = i
-    b = a + i
-    lst: List[int] = [a, b]
-""".strip()
+        for i in range(10):
+            a: int = i
+            b = a + i
+            lst: List[int] = [a, b]
+        """
     mapping = compute_lineno_to_stmt_mapping(code)
     assert isinstance(mapping[1], ast.For)
     assert isinstance(mapping[2], ast.AnnAssign)
@@ -30,17 +33,17 @@ for i in range(10):
 
 def test_multiline_for_loop():
     code = """
-for i in [
-    0,
-    1,
-    2,
-    3,
-    4,
-]:
-    a = i
-    b = a + i
-    lst = [a, b]
-""".strip()
+        for i in [
+            0,
+            1,
+            2,
+            3,
+            4,
+        ]:
+            a = i
+            b = a + i
+            lst = [a, b]
+        """
     mapping = compute_lineno_to_stmt_mapping(code)
     # for i in range(1, 7):
     #     assert isinstance(mapping[i], ast.For)
@@ -55,11 +58,11 @@ for i in [
 
 def test_if():
     code = """
-if True:
-    x = 0
-else:
-    x: int = 0
-""".strip()
+        if True:
+            x = 0
+        else:
+            x: int = 0
+        """
     mapping = compute_lineno_to_stmt_mapping(code)
     assert isinstance(mapping[1], ast.If)
     assert isinstance(mapping[2], ast.Assign)
